cmd

package
v0.0.0-...-a758588 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:   "gdupes DIRECTORY...",
	Short: "A multithreaded CLI tool for identifying duplicate files",
	Long:  `gdupes is a multithreaded command-line tool for identifying duplicate files.`,
	RunE: func(cmd *cobra.Command, args []string) error {
		_, err := gdupes.Run(&config, args)
		return err
	},
}

RootCmd represents the base command when called without any subcommands

Functions

func Execute

func Execute()

Execute adds all child commands to the root command sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

This section is empty.

Jump to